# -*- coding: utf-8 -*-
from setuphelpers import *

# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls
bin_name_sub = "pf7"
app_uninstallkey = "Photofiltre7"
app_dir = makepath(programfiles32, app_uninstallkey)
app_bin_path = makepath(app_dir, "PhotoFiltre7.exe")


def install():

    # Declaring local variables
    package_version = control.get_software_version()
    impacted_process_list = control.impacted_process.split(",")
    bin_name = glob.glob("*%s*.zip" % bin_name_sub)[0]
    app_name = control.name
    non_portable_uninstall = makepath(programfiles32, "PhotoFiltre 7", "Uninst.exe")
    # uninstalling non portable version :

    if isfile(non_portable_uninstall):
        run('"%s" /S' % non_portable_uninstall)
        unregister_uninstall("PhotoFiltre")
        remove_programs_menu_shortcut("PhotoFiltre 7", folder="PhotoFiltre 7")

    # Getting installed software version
    if isfile(app_bin_path):
        installed_version = get_version_from_binary(app_name)
    else:
        installed_version = ""

    # Installing the software
    print("Installing: %s" % app_name)
    if installed_version < package_version:
        killalltasks(impacted_process_list)
        if isdir(app_dir):
            remove_tree(app_dir)
        mkdirs(app_dir)
        print("Extracting: %s to: %s " % (bin_name, app_dir))
        unzip(bin_name, ".")
        temp_dir = "PhotoFiltre7"
        for file_to_move in glob.glob("%s/*" % temp_dir):
            shutil.move(file_to_move, app_dir)
        create_programs_menu_shortcut(app_name, app_bin_path)

        # Adding the software to the "list-registry"
        register_windows_uninstall(control)  # control is a PackageEntry object corresponding to the package
    else:
        print("%s portable is already installed in the correct version" % app_name)


def uninstall():
    # Declaring local variables
    impacted_process_list = control.version.split(",")

    # Uninstalling the software
    print("Uninstalling: %s" % app_uninstallkey)
    killalltasks(impacted_process_list)
    if isdir(app_dir):
        remove_tree(app_dir)
    unregister_uninstall("PhotoFiltre")
    remove_programs_menu_shortcut("PhotoFiltre")


def audit():
    # Declaring local variables
    package_version = control.version.split("-")[0]
    app_version = get_version_from_binary(app_bin_path, property_name="FileVersion")

    if isdir(app_dir):
        if package_version == app_version:
            print("OK: Folder exists: %s" % app_dir)
            return "OK"
        else:
            print("WARNING app version %s != %s package_version" % (app_version, package_version))
            return "WARNING"
    else:
        print("ERROR: Folder not exists: %s" % app_dir)
        return "ERROR"
